/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2006, 2012. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
 
window.$ = window.jQuery = WLJQ;
var busy,
	BUSY_COLOR = '#1D4885',
	WORKLIGHT_URL = 'https://www.ibm.com/developerworks/mobile/',
	feedTitleMaxLen = 120,
	response,
	// Static members - Worklight adapter
	FEEDS_ADAPTER = 'WorklightStarterAdapter',
	GET_FEEDS = 'getEngadgetFeeds',
	// Static members - Tabs
	FEEDS_TAB = '#feedsWrapper',
	FEEDS_DESCRIPTION_TAB = '#feedDescriptionTab',
	ABOUT_TAB = '#aboutTab';

function wlCommonInit() {
	beforeInitEnv();
	// Common initialization code goes here
	// initialize the busy indicator
	initializeBusy();
	busy.show();
	
	// Show tabs only after application successfully initializes
	$('.tab').removeClass('hidden');

	// Select the feed tab
	selectTab(FEEDS_TAB);
	afterInitEnv();
	
	// Set observers
	setObservers();
	
	WL.Client.connect({
		onSuccess : loadFeeds // Load data 
	});
}

//empty function, will be used by environments to add functionality before the common wlCommonInit functions
function beforeInitEnv() {
	
}

function initializeBusy() {
	busy = new WL.BusyIndicator('content', {color : BUSY_COLOR});
}

function setObservers() {
	$('#backLink').click(function(){
		selectTab(FEEDS_TAB);
	});
	$('#about').click(function(){
		selectTab(ABOUT_TAB);
	});
	$('#backToFeeds').click(function(){
		selectTab(FEEDS_TAB);
	});
	$('#reload').click(function(){
		loadFeeds();
	});
	$('#aboutWorklightLink').click(function(){
		location.href = WORKLIGHT_URL;
	});
}

function selectTab(tabId, item, li) {
	switch (tabId) {
	case FEEDS_TAB:
		displayFeedsTab();
		break;
	case FEEDS_DESCRIPTION_TAB:
		displayFeedDescriptionTab(item);
		break;
	case ABOUT_TAB:
		displayAboutTab();
		break;
	}
	showOnlyOneTab(tabId);
	afterSelectTab(tabId);
}

function displayFeedsTab() {
	$('#backToFeeds').hide();
	$('#about').show();
}

function displayFeedDescriptionTab(item) {
	displayFeedDescriptionTabEnvBeginning();
	
	// Get all old links and stop observing them
	$('#description a').unbind();
	$('#feedTitle').unbind('click');
	
	// Update the title
	$('#feedTitle').html(trimString(item.title, feedTitleMaxLen));
	$('#feedPubDate').html(item.pubDate);
	// Update the content
	$('#description').html(item.description);
	// Set observer
	$('#feedTitle').click(function(){
		WL.App.openURL(item.link, '_blank');
	});
	// Get all links and open them with openURL
	$('#description a').click(function (event) {
		event.preventDefault();
		WL.App.openURL(event.target.href, '_blank');
	});
}

//empty function, will be used by environments to add functionality to the displayFeedDescriptionTab function
function displayFeedDescriptionTabEnvBeginning() {
	
}

function displayAboutTab() {
	$('#about').hide();
	$('#backToFeeds').show();
}

function showOnlyOneTab(tabId) {
	// Hide all tabs
	$('.tab').hide();
	// Display the selected tab
	$(tabId).show();
}

//empty function, will be used by environments to add functionality after the selectTab function
function afterSelectTab() {
	
}

function loadFeeds() {
	//Show the busy indicator
	busy.show();

	// Invocation data details
	var invocationData = {
		// Adapter to invoke
		adapter: FEEDS_ADAPTER,
		// Procedure to invoke
		procedure: GET_FEEDS,
		parameters: []
	};

	// Invoke procedure
	WL.Client.invokeProcedure(invocationData, {
		// On success callback
		onSuccess : onGetFeedsSuccess,
		// On failure callback
		onFailure : onGetFeedsFail,
		// timeout
		timeout : 30000
	});
}

function onGetFeedsSuccess(response) {
	try {
		// Display the items
		displayItems(response.invocationResult.items);
	} catch (e) {
		// Unexpected error occurred
		WLAlert(Messages.unexpectedError);
	} finally {
		// Hide the busy indicator
		busy.hide();
	}
}

function onGetFeedsFail(response) {
	// Hide the busy indicator
	busy.hide();
	// Display the error
	WLAlert(Messages.failToPerformAction);
}

// Display items
function displayItems(items) {
	var ul = $('#itemsList'), i, item, li, text;
	var getCurrentItem = function (item, li) {
		return function() {
			selectTab(FEEDS_DESCRIPTION_TAB, item, li);
		};
	};
	// Remove previous items
	ul.empty();
	// Loop through the items
	for (i = 0; i < items.length; i += 1) {
		item = items[i];
		// Create new <li> element
		li = $('<li/>');
		// Create new <a> element
		text = $('<a/>', {'url' : item.link, 'class' : 'feedTitle'}).html(item.title);
		// Append the text element to the li element
		li.append(text);
		// Call display publication date function
		displayPubDate(item, li);	
		// Add an observer to the link, after the link was added to the DOM
		// the li is for the iPad optimization
		li.click(getCurrentItem(item, li));
		// Append the li element to the ul element
		ul.append(li);
		
		
		
		
	}
	afterDisplayItems();
}

function displayPubDate(item, li) {
	var pubDate = $('<div/>', {'class' : 'pubDate'}).html(item.pubDate);
	li.append(pubDate);
}

//empty function, will be used by environments to add functionality after the displayItems function
function afterDisplayItems() {
	
}

//empty function, will be used by environments to add functionality after the common wlCommonInit functions
function afterInitEnv() {
	
}

